==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/template/barnraiser_01/recommend.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_recommend" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="b_module_id" value="<?php if (isset($bookmark)) { echo $bookmark['module_id'];}?>" />
<input type="hidden" name="b_item_id" value="<?php if (isset($bookmark)) { echo $bookmark['item_id'];}?>" />
<input type="hidden" name="b_inner_item_id" value="<?php if (isset($bookmark)) { echo $bookmark['inner_item_id'];}?>" />


<div class="col_main">
	<?php
	if (isset($bookmark)) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_recommend'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_recommend'];?>: <?php echo $bookmark['item']['item_title'];?><br />
				</p>
				
				<p>
					<label for="id_recommend_note"><?php echo $lang['txt_recommend_note'];?></label>
					<textarea id="id_recommend_note" name="recommend_note" cols="72" rows="2"></textarea>
				
					<br />
				</p>
				
				<?php
				if (isset($subjects)) {
				?>
				<p>
					<label for="id_subject_id"><?php echo $lang['txt_recent_subjects'];?></label>
					<select name="subject_id" id="id_subject_id">
						<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
						<?php foreach($subjects as $key => $i): ?>
						<option value="<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></option>
						<?php endforeach; ?>
					</select><br />
				</p>
				<?php }?>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="insert_group_bookmark" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<br />
			</p>
			</div>
		</div>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_recommended'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (!empty($recommendations)) { 
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php 
					foreach($recommendations as $i): 
					?>
					<tr>
						<td valign="top">
							recommended by 
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity_nic'];?></a>, 
							<?php echo $this->date->formatDate($i['recommend_create_datetime']);?><br />
							<?php
							if (!empty($i['recommend_note'])) {
							?>
								<i>"<?php echo $i['recommend_note'];?>"</i><br />
							<?php }?>
						</td>
						<td valign="top">
							<a href="<?php echo $i['item']['item_url'];?>"><b><?php echo $i['item']['item_title'];?></b></a><br />
						</td>
						<td valign="top" align="right">
							<?php
							if (!empty($i['subject_id'])) {
							?>
								<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>">
								<img src="<?php echo $template_path;?>img/discuss.png" alt="<?php echo $lang['txt_discuss'];?>" border="0" title="<?php echo $lang['txt_discuss'];?>" /></a><br />
							<?php }?>
							<br />
						</td>
						<td valign="top" align="right">
							<?php
							if ($i['user_id'] == $_SESSION['user_id']) {
							$cell = $i['module_id'] . "-" . $i['item_id'] . "-" . $i['inner_item_id'] . "-" . $i['subject_id'];
							?>
								<input type="checkbox" name="recommendations[]" value="<?php echo $cell;?>" /><br />
							<?php }?>
						</td>			
					</tr>
					<?php endforeach; ?>
				</table>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="remove_group_bookmark" class="input_submit" value="<?php echo $lang['sub_remove'];?>" />
				<br />
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_bookmarks'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (!empty($bookmarks)) {
				?>
				<table cellspacing="1" cellpadding="2" border="0" width="100%">
				<?php
				foreach($bookmarks as $i): 
				?>
				<tr>
					<td align="top">
						<a href="<?php echo $i['item']['item_url'];?>"><?php echo $i['item']['item_title'];?></a><br />
					</td>
					<td align="top" align="right">
						<a href="index.php?amn=grp_recommend&amp;group_id=<?php echo $group['group_id'];?>&amp;b_module_id=<?php echo $i['module_id'];?>&amp;b_item_id=<?php echo $i['item_id'];?>&amp;b_inner_item_id=<?php echo $i['inner_item_id'];?>">&#43;</a><br/>
					</td>
				</tr>
				<?php 
				endforeach;
				?>
				</table>
				<?php
				}
				else {
					$lang['err_no_bookmarks'] = str_replace('SYS_KEYWORD_ICON', "<img src='" . $template_path_core . "img/mark.png' />", $lang['err_no_bookmarks']);
					echo $lang['err_no_bookmarks'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_grp_0_4.zip: am_mod_grp_0_4/components/grp/template/barnraiser_01/recommend.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=grp_recommend" method="post" name="frm" id="id_frm">
<input type="hidden" name="group_id" value="<?php echo $group['group_id'];?>" />
<input type="hidden" name="b_module_id" value="<?php if (isset($bookmark)) { echo $bookmark['module_id'];}?>" />
<input type="hidden" name="b_item_id" value="<?php if (isset($bookmark)) { echo $bookmark['item_id'];}?>" />
<input type="hidden" name="b_inner_item_id" value="<?php if (isset($bookmark)) { echo $bookmark['inner_item_id'];}?>" />


<div class="col_main">
	<?php
	if (isset($bookmark)) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_recommend'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<?php echo $lang['txt_recommend'];?>: <?php echo $bookmark['item']['item_title'];?><br />
				</p>
				
				<p>
					<label for="id_recommend_note"><?php echo $lang['txt_recommend_note'];?></label>
					<textarea id="id_recommend_note" name="recommend_note" cols="72" rows="2"></textarea>
				
					<br />
				</p>
				
				<?php
				if (isset($subjects)) {
				?>
				<p>
					<?php echo $lang['txt_recommend_subject'];?><br />
				</p>
				
				<p>
					<label for="id_subject_id"><?php echo $lang['txt_recent_subjects'];?></label>
					<select name="subject_id" id="id_subject_id">
						<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
						<?php foreach($subjects as $key => $i): ?>
						<option value="<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></option>
						<?php endforeach; ?>
					</select><br />
				</p>
				<?php }?>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="insert_group_bookmark" class="input_submit" value="<?php echo $lang['sub_insert'];?>" />
				<br />
			</p>
			</div>
		</div>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_recommended'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (!empty($recommendations)) { 
				?>
				<table cellspacing="1" cellpadding="4" border="0" width="100%">
					<?php 
					foreach($recommendations as $i): 
					?>
					<tr>
						<td valign="top">
							recommended by 
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['group'];?>&amp;identity_id=<?php echo $i['identity_id'];?>&amp;group_id=<?php echo $group['group_id'];?>">
							<?php echo $i['identity_nic'];?></a>, 
							<?php echo $this->date->formatDate($i['recommend_create_datetime']);?><br />
							<?php
							if (!empty($i['recommend_note'])) {
							?>
								<i>"<?php echo $i['recommend_note'];?>"</i><br />
							<?php }?>
						</td>
						<td valign="top">
							<a href="<?php echo $i['item']['item_url'];?>"><b><?php echo $i['item']['item_title'];?></b></a><br />
						</td>
						<td valign="top" align="right">
							<?php
							if (!empty($i['subject_id'])) {
							?>
								<a href="index.php?amn=grp_forum_subject&amp;group_id=<?php echo $group['group_id'];?>&amp;subject_id=<?php echo $i['subject_id'];?>">
								<img src="<?php echo $template_path;?>img/discuss.png" alt="<?php echo $lang['txt_discuss'];?>" border="0" title="<?php echo $lang['txt_discuss'];?>" /></a><br />
							<?php }?>
							<br />
						</td>
						<td valign="top" align="right">
							<?php
							if ($i['user_id'] == $_SESSION['user_id']) {
							$cell = $i['module_id'] . "-" . $i['item_id'] . "-" . $i['inner_item_id'] . "-" . $i['subject_id'];
							?>
								<input type="checkbox" name="recommendations[]" value="<?php echo $cell;?>" /><br />
							<?php }?>
						</td>
					</tr>
					<?php endforeach; ?>
				</table>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="remove_group_bookmark" class="input_submit" value="<?php echo $lang['sub_remove'];?>" />
				<br />
				<?php
				}
				else {
					echo $lang['template_error']['err_no_items'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_bookmarks'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (!empty($bookmarks)) {
				?>
				<table cellspacing="1" cellpadding="2" border="0" width="100%">
				<?php
				foreach($bookmarks as $i): 
				?>
				<tr>
					<td align="top">
						<a href="<?php echo $i['item']['item_url'];?>"><?php echo $i['item']['item_title'];?></a><br />
					</td>
					<td align="top" align="right">
						<a href="index.php?amn=grp_recommend&amp;group_id=<?php echo $group['group_id'];?>&amp;b_module_id=<?php echo $i['module_id'];?>&amp;b_item_id=<?php echo $i['item_id'];?>&amp;b_inner_item_id=<?php echo $i['inner_item_id'];?>">&#43;</a><br/>
					</td>
				</tr>
				<?php 
				endforeach;
				?>
				</table>
				<?php
				}
				else {
					$lang['err_no_bookmarks'] = str_replace('SYS_KEYWORD_ICON', "<img src='" . $template_path_core . "img/mark.png' />", $lang['err_no_bookmarks']);
					echo $lang['err_no_bookmarks'];
				}
				?>
				<br />
			</div>
		</div>
	</div>
</div>
</form>
